@@ -14,7 +14,7 @@ from aesara.scan.utils import expand_empty, safe_new, until
 from aesara.tensor.basic import get_scalar_constant_value
 from aesara.tensor.exceptions import NotScalarConstantError
 from aesara.tensor.math import minimum
-from aesara.tensor.shape import shape_padleft
+from aesara.tensor.shape import shape_padleft, unbroadcast
 from aesara.tensor.type import TensorType, integer_dtypes
 from aesara.updates import OrderedUpdates
 
@@ -751,7 +751,7 @@ def scan(
             # defined in scan utils
             sit_sot_scan_inputs.append(
                 expand_empty(
-                    at.unbroadcast(shape_padleft(actual_arg), 0),
+                    unbroadcast(shape_padleft(actual_arg), 0),
                     actual_n_steps,
                 )
             )
@@ -881,7 +881,7 @@ def scan(
             # this will represent only a slice and it will have one
             # dimension less.
             if isinstance(inner_out.type, TensorType) and return_steps.get(pos, 0) != 1:
-                outputs[pos] = at.unbroadcast(shape_padleft(inner_out), 0)
+                outputs[pos] = unbroadcast(shape_padleft(inner_out), 0)
 
         if not return_list and len(outputs) == 1:
             outputs = outputs[0]
@@ -1010,7 +1010,7 @@ def scan(
                 sit_sot_inner_inputs.append(new_var)
                 sit_sot_scan_inputs.append(
                     expand_empty(
-                        at.unbroadcast(shape_padleft(input.variable), 0),
+                        unbroadcast(shape_padleft(input.variable), 0),
                         actual_n_steps,
                     )
                 )
