@@ -12,10 +12,9 @@ import aesara.tensor.basic as at
 import aesara.tensor.math as tm
 from aesara.gradient import DisconnectedType
 from aesara.graph.basic import Apply, Constant, Variable
-from aesara.graph.op import OpenMPOp
-from aesara.graph.params_type import ParamsType
-from aesara.graph.type import EnumList
 from aesara.graph.utils import MethodNotDefined
+from aesara.link.c.op import OpenMPOp
+from aesara.link.c.params_type import ParamsType
 from aesara.scalar import bool as bool_t
 from aesara.tensor.type import TensorType, int_dtypes
 
@@ -147,12 +146,7 @@ def pool_2d(
             "pool_2d() will have the parameter ignore_border"
             " default value changed to True (currently"
             " False). To have consistent behavior with all Aesara"
-            " version, explicitly add the parameter ignore_border=True."
-            " On the GPU, using ignore_border=True is needed to use cuDNN."
-            " When using ignore_border=False and not using cuDNN, the only"
-            " GPU combination supported is when"
-            " `ws == stride and pad == (0, 0) and mode == 'max'`."
-            " Otherwise, the convolution will be executed on CPU.",
+            " version, explicitly add the parameter ignore_border=True.",
             category=DeprecationWarning,
             stacklevel=2,
         )
@@ -268,12 +262,7 @@ def pool_3d(
             "pool_3d() will have the parameter ignore_border"
             " default value changed to True (currently"
             " False). To have consistent behavior with all Aesara"
-            " version, explicitly add the parameter ignore_border=True."
-            " On the GPU, using ignore_border=True is needed to use cuDNN."
-            " When using ignore_border=False and not using cuDNN, the only"
-            " GPU combination supported is when"
-            " `ws == stride and pad == (0, 0, 0) and mode == 'max'`."
-            " Otherwise, the convolution will be executed on CPU.",
+            " version, explicitly add the parameter ignore_border=True.",
             category=DeprecationWarning,
             stacklevel=2,
         )
@@ -283,18 +272,6 @@ def pool_3d(
     return output
 
 
-# NB: This enum type is currently used in gpuarray/pool.py.
-# It may be used later as op param in this current file.
-# Enum name and constants names are inspired from cuDNN type `cudnnPoolingMode_t`
-# (cf. `aesara/gpuarray/cudnn_defs.py`).
-PoolingMode_t = EnumList(
-    ("POOLING_MAX", "max"),
-    ("POOLING_SUM", "sum"),
-    ("POOLING_AVERAGE_COUNT_INCLUDE_PADDING", "average_inc_pad"),
-    ("POOLING_AVERAGE_COUNT_EXCLUDE_PADDING", "average_exc_pad"),
-)
-
-
 class Pool(OpenMPOp):
     """
     sum or average over different patches.
